"use client";

import Image from "next/image";
import { useState } from "react";

import { motion } from "framer-motion";

import BlurFade from "@/components/ui/blur-fade";
import { ImageBaseUrl } from "@/configs/api";

function ServiceImages({
	thumbnail,
	images,
}: {
	thumbnail: any;
	images: any;
}) {
	const [selectedImage, setSelectedImage] = useState(thumbnail?.id);

	return (
		<BlurFade
			direction="right"
			delay={0.25}
			inViewMargin="-120px"
			inView
			className="flex flex-col items-center gap-6"
		>
			<motion.div
				key={selectedImage}
				initial={{ opacity: 0, scale: 0.8 }}
				animate={{ opacity: 1, scale: 1 }}
				exit={{ opacity: 0, scale: 0.8 }}
				transition={{ duration: 0.5 }}
			>
				<Image
					src={ImageBaseUrl + thumbnail?.image_path}
					alt={thumbnail?.name}
					width={599}
					height={450}
					className="h-[450px] w-full rounded-[10px] object-cover md:w-[599px]"
				/>
			</motion.div>

			<div className="flex w-full flex-wrap items-center justify-start -ml-24 gap-4">
				{images?.map((image: any) => (
					<motion.div
						key={image?.id}
						className="relative h-[80px] w-[80px] cursor-pointer overflow-hidden rounded-lg md:h-[100px] md:w-[100px]"
						style={{ border: "2px solid #FFFFFF" }}
						whileHover={{ scale: 1.1 }}
						onClick={() => setSelectedImage(image?.id)}
					>
						<Image
							src={ImageBaseUrl + image?.image_path}
							alt={image?.name}
							fill
							style={{
								objectFit: "cover",
							}}
						/>
					</motion.div>
				))}
			</div>
		</BlurFade>
	);
}

export default ServiceImages;
